crystal_toolkit.helpers.utils module — Crystal Toolkit documentation

# crystal_toolkit.helpers.utils module

crystal_toolkit.helpers.utils.update_object_args(d_args, object_name, allowed_args)

  Read default properties and overwrite them if user input exists

  Parameters

    - properties (d_args {dict} -- User defined) –

    - object (object_name {str} -- Name of) –

    - pythreejs (allowed_kwargs {List[str]} -- Used to limit the data that is passed to) –

  Returns

    Dictionary – Properties of object after userinput and default values are considered